@@ -1,22 +1,27 @@
-#' Convert MCMC chain to data.frame
+#' Convert MCMC Output to data.frame
 #'
-#' Converts the MCMC chain output of \code{\link{run_mcmc}} to data.frame.
+#' Converts the MCMC output of \code{\link{run_mcmc}} to \code{data.frame}.
 #'  
 #' @method as.data.frame mcmc_output
-#' @param x Output from \code{\link{run_mcmc}}.
+#' @param x Object of class \code{mcmc_output} from \code{\link{run_mcmc}}.
 #' @param row.names Ignored.
 #' @param optional Ignored.
 #' @param variable Return samples of \code{"theta"} (default) or 
 #' \code{"states"}?
-#' @param times Vector of indices. In case of states, 
+#' @param times A vector of indices. In case of states, 
 #' what time points to return? Default is all.
-#' @param states Vector of indices. In case of states, 
+#' @param states A vector of indices. In case of states, 
 #' what states to return? Default is all.
 #' @param expand Should the jump-chain be expanded? 
-#' Defaults to \code{TRUE} for non-IS-MCMC, and \code{FALSE} for IS-MCMC. 
+#' Defaults to \code{TRUE}. 
 #' For \code{expand = FALSE} and always for IS-MCMC, 
 #' the resulting data.frame contains variable weight (= counts * IS-weights).
+#' @param use_times If \code{TRUE} (default), transforms the values of the time 
+#' variable to match the ts attribute of the input to define. If \code{FALSE}, 
+#' time is based on the indexing starting from 1.
 #' @param ... Ignored.
+#' @seealso \code{as_draws} which converts the output for 
+#' \code{as_draws} object.
 #' @export
 #' @examples
 #' data("poisson_series")
@@ -33,16 +38,18 @@
 #' head(as.data.frame(out, variable = "theta", expand = FALSE))
 #' 
 #' # IS-weighted version:
-#' out_is <- run_mcmc(model, iter = 2000, particles = 10, mcmc_type  = "is2")
+#' out_is <- run_mcmc(model, iter = 2000, particles = 10, 
+#'   mcmc_type  = "is2")
 #' head(as.data.frame(out_is, variable = "theta"))
 #' 
 as.data.frame.mcmc_output <- function(x, 
   row.names, optional,
   variable = c("theta", "states"),
   times, states,
-  expand = !(x$mcmc_type %in% paste0("is", 1:3)), ...) {
+  expand = TRUE, 
+  use_times = TRUE, ...) {
   
-  variable <- match.arg(variable, c("theta", "states"))
+  variable <- match.arg(tolower(variable), c("theta", "states"))
   
   if (variable == "theta") {
     if (expand) {
@@ -77,9 +84,11 @@ as.data.frame.mcmc_output <- function(x,
       weights <- x$counts * 
         (if (x$mcmc_type %in% paste0("is", 1:3)) x$weights else 1)
     }
-    times <- time(ts(seq_len(nrow(x$alpha)), 
-      start = attr(x, "ts")$start, 
-      frequency = attr(x, "ts")$frequency))[times]
+    if (use_times) {
+      times <- time(ts(seq_len(nrow(x$alpha)), 
+        start = attr(x, "ts")$start, 
+        frequency = attr(x, "ts")$frequency))[times]
+    }
     d <- data.frame(iter = iters,
       value = as.numeric(values),
       variable = rep(colnames(x$alpha)[states], each = nrow(values)),
