@@ -1,10 +1,12 @@
 #' Particle Smoothing
 #'
 #' Function \code{particle_smoother} performs particle smoothing 
-#' based on either bootstrap particle filter [1], \eqn{\psi}-auxiliary 
-#' particle filter (\eqn{\psi}-APF) [2], 
-#' or extended Kalman particle filter [3] (or its iterated version [4]). 
-#' The smoothing phase is based on the filter-smoother algorithm by [5].
+#' based on either bootstrap particle filter (Gordon et al. 1993), 
+#' \eqn{\psi}-auxiliary particle filter (\eqn{\psi}-APF) (Vihola et al. 2020), 
+#' extended Kalman particle filter (Van Der Merwe et al. 2001), 
+#' or its version based on iterated EKF (Jazwinski, 1970). 
+#' The smoothing phase is based on the filter-smoother algorithm by 
+#' Kitagawa (1996).
 #' 
 #' See one of the vignettes for \eqn{\psi}-APF in case of nonlinear models.
 #'
@@ -17,6 +19,11 @@
 #' and \code{"psi"} (\eqn{\psi}-APF, the default for other models), and 
 #' for non-linear models option \code{"ekf"} (extended Kalman particle filter) 
 #' is also available.
+#' @param particles Number of particles as a positive integer. Suitable values 
+#' depend on the model, the data, and the chosen algorithm. While larger values 
+#' provide more accurate estimates, the run time also increases with respect to 
+#' the number of particles, so it is generally a good idea to test the filter 
+#' first with a small number of particles, e.g., less than 100.
 #' @param max_iter Maximum number of iterations used in Gaussian approximation,
 #' as a positive integer. 
 #' Default is 100 (although typically only few iterations are needed).
@@ -33,31 +40,35 @@
 #'  of the states and 
 #'  estimated log-likelihood (\code{logLik}).
 #' @references 
-#' [1] Gordon, NJ, Salmond, DJ, Smith, AFM (1993). 
+#' Gordon, NJ, Salmond, DJ, Smith, AFM (1993). 
 #' Novel approach to nonlinear/non-Gaussian Bayesian state estimation. 
 #' IEE Proceedings-F, 140, 107-113.
+#' https://doi.org/10.1049/ip-f-2.1993.0015 
 #' 
-#' [2] Vihola, M, Helske, J, Franks, J. Importance sampling type estimators 
+#' Vihola, M, Helske, J, Franks, J. Importance sampling type estimators 
 #' based on approximate marginal Markov chain Monte Carlo. 
-#' Scand J Statist. 2020; 1-38. https://doi.org/10.1111/sjos.12492
+#' Scand J Statist. 2020; 1-38. 
+#' https://doi.org/10.1111/sjos.12492
 #' 
-#' [3] Van Der Merwe, R, Doucet, A, De Freitas, N,  Wan, EA (2001). 
+#' Van Der Merwe, R, Doucet, A, De Freitas, N,  Wan, EA (2001). 
 #' The unscented particle filter. 
 #' In Advances in neural information processing systems, p 584-590.
 #' 
-#' [4] Jazwinski, A 1970. Stochastic Processes and Filtering Theory. 
+#' Jazwinski, A 1970. Stochastic Processes and Filtering Theory. 
 #' Academic Press.
 #' 
-#' [5] Kitagawa, G (1996). Monte Carlo filter and smoother for non-Gaussian 
+#' Kitagawa, G (1996). Monte Carlo filter and smoother for non-Gaussian 
 #' nonlinear state space models. 
 #' Journal of Computational and Graphical Statistics, 5, 1-25.
+#' https://doi.org/10.2307/1390750
+#' 
 #' @export
 #' @rdname particle_smoother
 particle_smoother <- function(model, particles, ...) {
   UseMethod("particle_smoother", model)
 }
 
-#' @method particle_smoother gaussian
+#' @method particle_smoother lineargaussian
 #' @export
 #' @rdname particle_smoother
 #' @examples 
@@ -71,9 +82,11 @@ particle_smoother <- function(model, particles, ...) {
 #'   use_antithetic = TRUE))
 #' ts.plot(out$alphahat, rowMeans(out2), col = 1:2)
 #' 
-particle_smoother.gaussian <- function(model, particles,  method = "psi",
+particle_smoother.lineargaussian <- function(model, particles,  method = "psi",
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
+  check_missingness(model)
+  
   if (missing(particles)) {
     nsim <- eval(match.call(expand.dots = TRUE)$nsim)
     if (!is.null(nsim)) {
@@ -83,15 +96,15 @@ particle_smoother.gaussian <- function(model, particles,  method = "psi",
     }
   }
   
-  particles <- check_integer(particles, "particles")
+  particles <- check_intmax(particles, "particles")
   
   nsamples <- ifelse(!is.null(nrow(model$y)), nrow(model$y), length(model$y)) * 
     length(model$a1) * particles
-  if (particles > 100 & nsamples > 1e12) {
+  if (particles > 100 & nsamples > 1e10) {
     warning(paste("Trying to sample ", nsamples, 
       "particles, you might run out of memory."))
   }
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
   
   if (method == "psi") {
     out <- list()
@@ -129,6 +142,8 @@ particle_smoother.nongaussian <- function(model, particles,
   seed = sample(.Machine$integer.max, size = 1), 
   max_iter = 100, conv_tol = 1e-8, ...) {
   
+  check_missingness(model)
+  
   if (missing(particles)) {
     nsim <- eval(match.call(expand.dots = TRUE)$nsim)
     if (!is.null(nsim)) {
@@ -137,19 +152,19 @@ particle_smoother.nongaussian <- function(model, particles,
       particles <- nsim
     }
   }
-  particles <- check_integer(particles, "particles")
+  particles <- check_intmax(particles, "particles")
   nsamples <- ifelse(!is.null(nrow(model$y)), nrow(model$y), length(model$y)) * 
     length(model$a1) * particles
-  if (particles > 100 & nsamples > 1e12) {
+  if (particles > 100 & nsamples > 1e10) {
     warning(paste("Trying to sample ", nsamples, 
       "particles, you might run out of memory."))
   }
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
   
-  model$max_iter <- check_integer(max_iter, "max_iter", positive = FALSE)
+  model$max_iter <- check_intmax(max_iter, "max_iter", positive = FALSE)
   model$conv_tol <- check_positive_real(conv_tol, "conv_tol")
   
-  method <- match.arg(method, c("bsf", "psi"))
+  method <- match.arg(tolower(method), c("bsf", "psi"))
 
   model$distribution <- pmatch(model$distribution,
     c("svm", "poisson", "binomial", "negative binomial", "gamma", "gaussian"), 
@@ -178,6 +193,8 @@ particle_smoother.ssm_nlg <- function(model, particles,
   seed = sample(.Machine$integer.max, size = 1),
   max_iter = 100, conv_tol = 1e-8, iekf_iter = 0, ...) {
   
+  check_missingness(model)
+  
   if (missing(particles)) {
     nsim <- eval(match.call(expand.dots = TRUE)$nsim)
     if (!is.null(nsim)) {
@@ -186,20 +203,20 @@ particle_smoother.ssm_nlg <- function(model, particles,
       particles <- nsim
     }
   }
-  particles <- check_integer(particles, "particles")
+  particles <- check_intmax(particles, "particles")
   
   nsamples <- ifelse(!is.null(nrow(model$y)), nrow(model$y), length(model$y)) * 
     model$n_states * particles
-  if (particles > 100 & nsamples > 1e12) {
+  if (particles > 100 & nsamples > 1e10) {
     warning(paste("Trying to sample ", nsamples, 
       "particles, you might run out of memory."))
   }
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
-  max_iter <- check_integer(max_iter, "max_iter", positive = FALSE)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
+  max_iter <- check_intmax(max_iter, "max_iter", positive = FALSE)
   conv_tol <- check_positive_real(conv_tol, "conv_tol")
-  iekf_iter <- check_integer(iekf_iter, "iekf_iter", positive = FALSE)
+  iekf_iter <- check_intmax(iekf_iter, "iekf_iter", positive = FALSE)
   
-  method <- match.arg(method, c("bsf", "psi", "ekf"))
+  method <- match.arg(tolower(method), c("bsf", "psi", "ekf"))
   
   out <- switch(method,
     psi = psi_smoother_nlg(t(model$y), model$Z, model$H, model$T, 
@@ -238,6 +255,8 @@ particle_smoother.ssm_nlg <- function(model, particles,
 particle_smoother.ssm_sde <- function(model, particles, L, 
   seed = sample(.Machine$integer.max, size = 1), ...) {
   
+  check_missingness(model)
+  
   if (L < 1) stop("Discretization level L must be larger than 0.")
   
   if (missing(particles)) {
@@ -248,13 +267,13 @@ particle_smoother.ssm_sde <- function(model, particles, L,
       particles <- nsim
     }
   }
-  particles <- check_integer(particles, "particles")
+  particles <- check_intmax(particles, "particles")
   nsamples <- length(model$y) * particles
-  if (particles > 100 & nsamples > 1e12) {
+  if (particles > 100 & nsamples > 1e10) {
     warning(paste("Trying to sample ", nsamples, 
       "particles, you might run out of memory."))
   }
-  seed <- check_integer(seed, "seed", FALSE, max = .Machine$integer.max)
+  seed <- check_intmax(seed, "seed", FALSE, max = .Machine$integer.max)
   out <-  bsf_smoother_sde(model$y, model$x0, model$positive, 
     model$drift, model$diffusion, model$ddiffusion, 
     model$prior_pdf, model$obs_pdf, model$theta, 
