@@ -12,22 +12,25 @@ Rcpp::List importance_sample_ng(const Rcpp::List model_,
   
   switch (model_type) { 
   case 0: {
-  ssm_mng model(model_, seed);
-  model.approximate();
-  arma::cube alpha = model.approx_model.simulate_states(nsim);
-  model.update_scales();
-  arma::vec weights = model.importance_weights(alpha);
-  weights = arma::exp(weights - arma::accu(model.scales));
-  return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
-    Rcpp::Named("weights") = weights);
-} break;
+    ssm_mng model(model_, seed);
+    model.approximate();
+    arma::cube alpha = model.approx_model.simulate_states(nsim);
+    model.update_scales();
+    arma::vec weights = model.importance_weights(alpha) - arma::accu(model.scales);
+    double maxw = weights.max();
+    weights = arma::exp(weights - maxw);
+    
+    return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
+      Rcpp::Named("weights") = weights);
+  } break;
   case 1: {
     ssm_ung model(model_, seed);
     model.approximate();
     arma::cube alpha = model.approx_model.simulate_states(nsim);
     model.update_scales();
-    arma::vec weights = model.importance_weights(alpha);
-    weights = arma::exp(weights - arma::accu(model.scales));
+    arma::vec weights = model.importance_weights(alpha) - arma::accu(model.scales);
+    double maxw = weights.max();
+    weights = arma::exp(weights - maxw);
     
     return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
       Rcpp::Named("weights") = weights);
@@ -37,8 +40,10 @@ Rcpp::List importance_sample_ng(const Rcpp::List model_,
     model.approximate();
     arma::cube alpha = model.approx_model.simulate_states(nsim);
     model.update_scales();
-    arma::vec weights = model.importance_weights(alpha);
-    weights = arma::exp(weights - arma::accu(model.scales));
+    arma::vec weights = model.importance_weights(alpha) - arma::accu(model.scales);
+    double maxw = weights.max();
+    weights = arma::exp(weights - maxw);
+    
     return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
       Rcpp::Named("weights") = weights);
   } break;
@@ -47,8 +52,10 @@ Rcpp::List importance_sample_ng(const Rcpp::List model_,
     model.approximate();
     arma::cube alpha = model.approx_model.simulate_states(nsim);
     model.update_scales();
-    arma::vec weights = model.importance_weights(alpha);
-    weights = arma::exp(weights - arma::accu(model.scales));
+    arma::vec weights = model.importance_weights(alpha) - arma::accu(model.scales);
+    double maxw = weights.max();
+    weights = arma::exp(weights - maxw);
+    
     return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
       Rcpp::Named("weights") = weights);
   } break;
@@ -57,8 +64,10 @@ Rcpp::List importance_sample_ng(const Rcpp::List model_,
     model.approximate();
     arma::cube alpha = model.approx_model.simulate_states(nsim);
     model.update_scales();
-    arma::vec weights = model.importance_weights(alpha);
-    weights = arma::exp(weights - arma::accu(model.scales));
+    arma::vec weights = model.importance_weights(alpha) - arma::accu(model.scales);
+    double maxw = weights.max();
+    weights = arma::exp(weights - maxw);
+    
     return Rcpp::List::create(Rcpp::Named("alpha") = alpha,
       Rcpp::Named("weights") = weights);
   } break;
